@@ -14,8 +14,9 @@
 #
 
 DESP_MST <-
-function(X,B) {
+function(X,B,Theta=NULL) {
   # estimation of the diagonal of the precision matrix using minimum spanning trees, when the true value of B is known or has already been estimated
+  # the observations of the data matrix X are assumed to have zero mean
 
   # read the sample size and the number of variables
   D = dim(X);
@@ -23,7 +24,14 @@ function(X,B) {
   p = D[2];               # p is the dimension
 
   # compute the sample cov matrix
-  S = crossprod(X)/n;
+  if(is.null(Theta))
+    {
+    S = crossprod(X)/n;
+    }
+  else
+    {
+    S = crossprod(X - Theta %*% MASS::ginv(B))/n;
+    }
   
   G = DESP_Weighted_Graph(B,n);
   trees = DESP_MST_MaxDegreeRoot(G);
